@@ -1,4 +1,4 @@
-from typing import Type, TypeVar
+from typing import Type, TypeVar, Generic
 
 from BotCore import DataBase
 from BotCore.ModelInfo import ModelInfo
@@ -6,7 +6,7 @@ from BotCore.ModelInfo import ModelInfo
 T = TypeVar("T", bound=ModelInfo)
 
 
-class DAO:
+class DAO(Generic[T]):
 
 	def __init__(self, database: DataBase, model: Type[T]):
 		self.database: DataBase = database
@@ -15,8 +15,8 @@ class DAO:
 	def create(self, **kwargs):
 		return self.database.update(
 			f"INSERT INTO {self.model.table()} ({', '.join(self.model.fields())}) "
-			f"VALUES ({', '.join('?' for _ in self.fields())})",
-			*[kwargs.get(field) for field in self.fields()]
+			f"VALUES ({', '.join('?' for _ in self.model.fields())})",
+			*[kwargs.get(field) for field in self.model.fields()]
 		)
 
 	def delete(self, row_id):
