@@ -1,15 +1,16 @@
 
-from typing import TypeVar, Generic, Type
+from typing import TypeVar, Type
 
 from BotCore import DAO
 from BotCore.ModelInfo import ModelInfo
 
 T = TypeVar("T", bound=ModelInfo)
+D = TypeVar("D", bound=DAO)
 
 
-class Service(Generic[T]):
+class Service:
 
-	def __init__(self, model: Type[T], dao: DAO[T]):
+	def __init__(self, model: Type[T], dao: D):
 		self.model = model
 		self.dao = dao
 
